<template>
  <DashboardLayout>
    <DashboardHeader>
      <DashboardTitle>{{ $t("app.dashboard.title") }}</DashboardTitle>
      <div>
        <FormDate
          v-model="filters.date"
          name="date"
          range
          required
        />
      </div>
    </DashboardHeader>
    <DashboardBody container>
      <LinksAnalyticsCharts :filters="filters" />
    </DashboardBody>
  </DashboardLayout>
</template>

<script lang="ts" setup>
import DashboardHeader from "@/js/contexts/shared/ui/components/dashboard/DashboardHeader.vue";
import DashboardBody from "@/js/contexts/shared/ui/components/dashboard/DashboardBody.vue";
import DashboardTitle from "@/js/contexts/shared/ui/components/dashboard/DashboardTitle.vue";
import DashboardLayout from "@/js/contexts/shared/ui/layouts/DashboardLayout.vue";
import useDayjs from "@/js/contexts/shared/composables/useDayjs";
import useFilters from "@/js/contexts/shared/composables/useFilters";
import type { LinkAnalyticsFilters } from "@/js/contexts/links/models/LinkAnalyticsFilters";
import FormDate from "@/js/contexts/form/ui/components/FormDate.vue";
import LinksAnalyticsCharts from "@/js/contexts/links/ui/components/LinksAnalyticsCharts.vue";

const { t } = useI18n();
const dayjs = useDayjs();

useHead({
  title: t("app.dashboard.title"),
});

const filters = useFilters<LinkAnalyticsFilters>(
  {
    date: { start: dayjs().subtract(6, "days").startOf("day").toDate(), end: dayjs().endOf("day").toDate() },
  },
  ["date"],
);
</script>
